# -*- coding: utf-8 -*-
# @Time    : 2020-06-24 11:50
# @Author  : xzr
# @File    : negotiation
# @Software: PyCharm
# @Contact : xzregg@gmail.com
# @Desc    : 

from django.utils.translation import gettext_lazy as _

from rest_framework.negotiation import DefaultContentNegotiation